﻿using Microsoft.SPOT.Hardware;
using Microtoolskit.Hardware.Displays;
using Microtoolskit.Hardware.Sensors;
using SecretLabs.NETMF.Hardware.NetduinoPlus;
using System.Threading;

namespace Incubateur
{
    public class Program
    {
        enum Etat : ushort
        {
            chaufferOn = 0,
            chaufferOff = 1
        }
        static bool ledOn = false;

        public static void Main()
        {
            // Variables
            var temperature = 0.0; // <- A compléter (IncubateurV1)
            var Tconsigne = 26.0;
            var ecart = 0.1;
            var ecartAlarme = 2.0;
            Etat etat = 0;

            // Thread
            var threadLed = new Thread(flashLed);  // plus loin

            // Création des objets virtuels  
            TMP102 ModuleMesureTemp = new TMP102();    // <- Objet ModuleMesureTemp à créer (IncubateurV1)
            ELCD162 Lcd = new ELCD162(); //  (donné)
            var CdeChauffage = new OutputPort(Pins.GPIO_PIN_D6, false);
            var Alarme = new PWM(PWMChannels.PWM_PIN_D10, 2000, 0.5, false);
            var pot = new AnalogInput(Cpu.AnalogChannel.ANALOG_0);

            // Initialisations (donné)
            ModuleMesureTemp.Init();
            Lcd.Init(); Lcd.ClearScreen(); Lcd.CursorOff(); // COM2
            Alarme.Stop();
            threadLed.Start();  // plus loin

            while (true)
            {
                // Mesurer la consigne et la température
                temperature = ModuleMesureTemp.ReadAsCelcius(); // <- A compléter (IncubateurV1)
                Tconsigne = pot.ReadRaw() * 0.0049 + 20.0; // plus loin

                // Traitement
                // Alarme
                if ((temperature > (Tconsigne + ecartAlarme)) || (temperature < (Tconsigne - ecartAlarme)))
                {
                    ledOn = true;//Alarme.Start();
                }
                else
                {
                    Alarme.Stop(); ledOn = false;
                }

                // Chauffage
                switch (etat)
                {
                    case Etat.chaufferOn:
                        CdeChauffage.Write(true);
                        if (temperature >= (Tconsigne + ecart))
                        {
                            etat = Etat.chaufferOff;
                        }
                        break;
                    case Etat.chaufferOff:
                        CdeChauffage.Write(false);
                        if (temperature <= (Tconsigne - ecart))
                        {
                            etat = Etat.chaufferOn;
                        }
                        break;
                    default:
                        break;
                }

                // Effacer le lcd
                Lcd.ClearScreen(); // <- A compléter (IncubateurV1)

                // Afficher la température sur le lcd
                Lcd.PutString("Csg = " + Tconsigne.ToString("F1") + "C");
                Lcd.SetCursor(0, 1);
                Lcd.PutString("T = " + temperature.ToString("F1") + "C"); // <- A compléter (IncubateurV1)

                Thread.Sleep(1000); // Attendre une seconde entre chaque mesure (donné)  
            }
        }
        #region Thread Ledflash
        static void flashLed() // plus loin
        {
            PWM led = new PWM(PWMChannels.PWM_PIN_D11, 1000,0.1,false);
            led.Start();

            while (true)
            {
                if (ledOn)
                {
                    led.Start();
                    for (var i=5.0;i<95.0;i++)
                    {
                        led.DutyCycle = i / 100;
                        Thread.Sleep(10);
                    }
                }
                else
                {
                    led.Stop();
                }
                
            }
        }
        #endregion
    }
}
